@@ -7,7 +7,8 @@ DEFAULT_EXCLUDE_EXTENSION = ["jar", "png", "exe", "so", "a", "dll", "jpeg", "jpg
                              "pfm", "otf", "afm", "dfont", "json"]
 OSS_PKG_INFO_FILES = [r"oss-pkg-info[\s\S]*.ya?ml", r"oss-package[\s\S]*.info", r"sbom-info[\s\S]*.ya?ml",
                       "requirement.txt", "requirements.txt", "package.json", "pom.xml", "build.gradle",
-                      "podfile.lock", "cartfile.resolved", "pubspec.yaml", "package.resolved", "go.mod"]
+                      "podfile.lock", "cartfile.resolved", "pubspec.yaml", "package.resolved", "go.mod",
+                      "packages.config", "project.assets.json"]
 HTML_RESULT_EXPAND_LIMIT = 10
 HTML_RESULT_PRINT_LIMIT = 100
 
